/* ver.B.b14.02(BLAZE) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"mxmap",
	"(C) 2000-2007 Hirohisa Mori",
	"ver.B.b14.02(BLAZE)",
	2007,2,28,
	0,
	"make matrix map ",
};

